# Gemini Outrun

**Outrun** game with Google Gemini AI integrated into it.

# Source Code

The source code of the game **Gemini Outrun** is available in [Source Code](https://github.com/SoftwareApkDev/gemini_outrun/blob/master/gemini_outrun/gemini_outrun.py).

# Installation

```
pip install gemini_outrun
```

# How to Run the Game?

Pre-requisites:

1. [Python](https://www.python.org/downloads/) installed in your device.
2. .env file in the same directory as <GEMINI_OUTRUN_DIRECTORY> and has the value of GEMINI_API_KEY.

```
cd <GEMINI_OUTRUN_DIRECTORY>
python gemini_outrun.py
```

**Note:** Replace <GEMINI_OUTRUN_DIRECTORY> with the path to the directory of the game **Gemini Outrun**.

Then, the game will start like as follows.

![Gameplay](images/Gameplay.png)

Press "UP" key to accelerate, "LEFT" key to move right, and "RIGHT" key to move left.
